Python: module TileStache.Goodies.ExternalConfigServer

TileStache.Goodies.ExternalConfigServer | index

`ExternalConfigServer is a replacement for WSGITileServer that uses external
configuration fetched via HTTP to service all config requests.
Example usage, with gunicorn (http://gunicorn.org):
gunicorn --bind localhost:8888 "TileStache.Goodies.ExternalConfigServer:WSGIServer(url)"`

Modules
`` |  |
TileStache | logging |  |

Classes
`` |  | TileStache.WSGITileServer WSGIServer DynamicLayers ExternalConfiguration
class DynamicLayers
`` |  | Methods defined here: __contains__(self, key) __getitem__(self, key) __init__(self, config, url_root, cache_responses, dirpath) items(self) keys(self) parse_layer(self, layer_json)
class ExternalConfiguration
`` |  | Methods defined here: __init__(self, url_root, cache_dict, cache_responses, dirpath)
class WSGIServer(TileStache.WSGITileServer)
`` | `Wrap WSGI application, passing it a custom configuration. The WSGI application is an instance of TileStache:WSGITileServer. This method is initiated with a url_root that contains the scheme, host, port and path that must prefix the API calls on our local server. Any valid http or https urls should work. The cache_responses parameter tells TileStache to cache all responses from the configuration server.`
| Methods defined here: __call__(self, environ, start_response) __init__(self, url_root, cache_responses=True, debug_level='DEBUG')